==> rustup_1.26.0.orig.tar.gz: rustup-1.26.0/README.md <==
# Rustup: the Rust toolchain installer

| Master CI    | Build Status                                             |
|--------------|----------------------------------------------------------|
| Windows      | ![Windows builds][actions-windows-master]                |
| macOS        | ![maOS builds][actions-macos-master]                     |
| Linux Etc    | ![Linux (etc) builds][actions-linux-master]              |

*Rustup* installs [The Rust Programming Language][rustlang] from the official
release channels, enabling you to easily switch between stable, beta,
and nightly compilers and keep them updated. It makes cross-compiling
simpler with binary builds of the standard library for common platforms.
And it runs on all platforms Rust supports, including Windows.

[rustlang]: https://www.rust-lang.org

## Documentation

See [**The Rustup book**](https://rust-lang.github.io/rustup/) for
documentation on installing and using Rustup.

## Contributing

See [CONTRIBUTING.md](CONTRIBUTING.md) for information on contributing to Rustup.

## License

Copyright Diggory Blake, the Mozilla Corporation, and Rustup
contributors.

Licensed under either of

* Apache License, Version 2.0, ([LICENSE-APACHE](LICENSE-APACHE) or https://www.apache.org/licenses/LICENSE-2.0)
* MIT license ([LICENSE-MIT](LICENSE-MIT) or https://opensource.org/licenses/MIT)

at your option.

<!-- Badges -->
[actions-windows-master]: https://github.com/rust-lang/rustup/workflows/Windows%20(master)/badge.svg
[actions-macos-master]: https://github.com/rust-lang/rustup/workflows/macOS/badge.svg?branch=master
[actions-linux-master]: https://github.com/rust-lang/rustup/workflows/Linux%20(master)/badge.svg

==> rustup_1.27.1.orig.tar.gz: rustup-1.27.1/README.md <==
# Rustup: the Rust toolchain installer

| Master CI    | Build Status                                             |
|--------------|----------------------------------------------------------|
| Windows      | ![Windows builds][actions-windows-master]                |
| macOS        | ![maOS builds][actions-macos-master]                     |
| Linux Etc    | ![Linux (etc) builds][actions-linux-master]              |

*Rustup* installs [The Rust Programming Language][rustlang] from the official
release channels, enabling you to easily switch between stable, beta,
and nightly compilers and keep them updated. It makes cross-compiling
simpler with binary builds of the standard library for common platforms.
And it runs on all platforms Rust supports, including Windows.

[rustlang]: https://www.rust-lang.org

## Documentation

See [**The Rustup book**](https://rust-lang.github.io/rustup/) for
documentation on installing and using Rustup.

## Contributing

See [**The Rustup dev guide**](https://rust-lang.github.io/rustup/dev-guide) for information on contributing to Rustup.

## License

Copyright Diggory Blake, the Mozilla Corporation, and Rustup
contributors.

Licensed under either of

* Apache License, Version 2.0, ([LICENSE-APACHE](LICENSE-APACHE) or https://www.apache.org/licenses/LICENSE-2.0)
* MIT license ([LICENSE-MIT](LICENSE-MIT) or https://opensource.org/licenses/MIT)

at your option.

<!-- Badges -->
[actions-windows-master]: https://github.com/rust-lang/rustup/workflows/Windows%20(master)/badge.svg
[actions-macos-master]: https://github.com/rust-lang/rustup/workflows/macOS/badge.svg?branch=master
[actions-linux-master]: https://github.com/rust-lang/rustup/workflows/Linux%20(master)/badge.svg
